# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['botocore-stubs']

package_data = \
{'': ['*'], 'botocore-stubs': ['crt/*', 'retries/*']}

install_requires = \
['types-awscrt']

setup_kwargs = {
    'name': 'botocore-stubs',
    'version': '1.27.93',
    'description': 'Type annotations and code completion for botocore',
    'long_description': '# botocore-stubs\n\n[![PyPI - botocore-stubs](https://img.shields.io/pypi/v/botocore-stubs.svg?color=blue&label=botocore-stubs)](https://pypi.org/project/botocore-stubs)\n[![PyPI - botocore](https://img.shields.io/pypi/v/botocore.svg?color=blue&label=botocore)](https://pypi.org/project/botocore)\n[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/botocore-stubs.svg?color=blue)](https://pypi.org/project/botocore-stubs)\n[![PyPI - Downloads](https://img.shields.io/pypi/dm/botocore-stubs?color=blue)](https://pypistats.org/packages/botocore-stubs)\n\n![boto3.typed](https://github.com/youtype/mypy_boto3_builder/raw/main/logo.png)\n\nType annotations and code completion for [botocore](https://pypi.org/project/botocore/) package.\nThis package is a part of [mypy_boto3_builder](https://github.com/youtype/mypy_boto3_builder) project.\n\n## Installation\n\n```bash\npython -m pip install botocore-stubs\n```\n\n## Usage\n\nUse [mypy](https://github.com/python/mypy) or [pyright](https://github.com/microsoft/pyright) for type checking.\n\n### Latest changes\n\nFull changelog can be found in [Releases](https://github.com/youtype/botocore-stubs/releases).\n\n## Versioning\n\n`botocore-stubs` version is the same as related `botocore` version and follows\n[PEP 440](https://www.python.org/dev/peps/pep-0440/) format.\n\n## Support and contributing\n\nPlease reports any bugs or request new features in\n[botocore-stubs](https://github.com/youtype/botocore-stubs/issues/) repository.\n',
    'author': 'Vlad Emelianov',
    'author_email': 'vlad.emelianov.nz@gmail.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://youtype.github.io/mypy_boto3_builder/',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.7,<4.0',
}


setup(**setup_kwargs)



import sys
from typing import Any, Mapping, Optional, Type

from botocore.awsrequest import AWSResponse as AWSResponse
from botocore.client import BaseClient
from botocore.exceptions import ParamValidationError as ParamValidationError
from botocore.exceptions import StubAssertionError as StubAssertionError
from botocore.exceptions import StubResponseError as StubResponseError
from botocore.exceptions import UnStubbedResponseError as UnStubbedResponseError
from botocore.validate import validate_parameters as validate_parameters

if sys.version_info >= (3, 9):
    from typing import Literal
else:
    from typing_extensions import Literal

class _ANY:
    def __eq__(self, other: object) -> Literal[True]: ...
    def __ne__(self, other: object) -> Literal[False]: ...

ANY: _ANY

class Stubber:
    def __init__(self, client: BaseClient) -> None:
        self.client: BaseClient = ...
    def __enter__(self) -> Stubber: ...
    def __exit__(
        self, exception_type: Type[Exception], exception_value: Any, traceback: Any
    ) -> None: ...
    def activate(self) -> None: ...
    def deactivate(self) -> None: ...
    def add_response(
        self,
        method: str,
        service_response: Mapping[str, Any],
        expected_params: Optional[Mapping[str, Any]] = ...,
    ) -> None: ...
    def add_client_error(
        self,
        method: str,
        service_error_code: str = ...,
        service_message: str = ...,
        http_status_code: int = ...,
        service_error_meta: Optional[Mapping[str, Any]] = ...,
        expected_params: Optional[Mapping[str, Any]] = ...,
        response_meta: Optional[Mapping[str, Any]] = ...,
        modeled_fields: Optional[Mapping[str, Any]] = ...,
    ) -> None: ...
    def assert_no_pending_responses(self) -> None: ...
